@@ -5,14 +5,14 @@ from zope.security.proxy import removeSecurityProxy
 def objectAdded( object, event ):
     if removeSecurityProxy:
         object = removeSecurityProxy( object )
-    interfaces.IOperationFactory( object ).add().store()
+    interfaces.IOperationFactory( object ).add()
     
 def objectModified( object, event ):
     if removeSecurityProxy:
         object = removeSecurityProxy( object )    
-    interfaces.IOperationFactory( object ).modify().store()    
+    interfaces.IOperationFactory( object ).modify()
     
 def objectDeleted( object, event ):
     if removeSecurityProxy:
         object = removeSecurityProxy( object )    
-    interfaces.IOperationFactory( object ).delete().store()    
+    interfaces.IOperationFactory( object ).remove()
